StrapiResponse class

callng Strapi.i.request will return this

Constructors

StrapiResponse({required int statusCode, required bool failed, required String error, required String errorMessage, required List<Map<String, dynamic>> body, required int count, required Uri? url})
object that is returned when you call Strapi.i.request

Properties

body → List<Map<String, dynamic>>
strapi json response body as dart map
final
count → int
number of entities in the response or the result of count api against a collection
final
error → String
short error message
final
errorMessage → String
error message
final
failed → bool
immediate check whether this response is failed or not i.e non ~200 code
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → int
http response code for the rquest made
final
url → Uri?
url the request is made against
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited